summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/dbconnectionsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/dbconnectionsimpl.cpp')
-rw-r--r--kdevdesigner/designer/dbconnectionsimpl.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kdevdesigner/designer/dbconnectionsimpl.cpp b/kdevdesigner/designer/dbconnectionsimpl.cpp
index 1d3c1a0b..00fb13eb 100644
--- a/kdevdesigner/designer/dbconnectionsimpl.cpp
+++ b/kdevdesigner/designer/dbconnectionsimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -45,25 +45,25 @@
static bool blockChanges = FALSE;
/*
* Constructs a DatabaseConnectionsEditor which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-DatabaseConnectionsEditor::DatabaseConnectionsEditor( Project *pro, TQWidget* parent, const char* name, bool modal, WFlags fl )
- : DatabaseConnectionBase( parent, name, modal, fl ), project( pro )
+DatabaseConnectionsEditor::DatabaseConnectionsEditor( Project *pro, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : DatabaseConnectionBase( tqparent, name, modal, fl ), project( pro )
{
connect( buttonHelp, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
connectionWidget = new DatabaseConnectionWidget( grp );
grpLayout->addWidget( connectionWidget, 0, 0 );
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
TQPtrList<DatabaseConnection> lst = project->databaseConnections();
for ( DatabaseConnection *conn = lst.first(); conn; conn = lst.next() )
listConnections->insertItem( conn->name() );
connectionWidget->comboDriver->insertStringList( TQSqlDatabase::drivers() );
#endif
- connectionWidget->editName->setValidator( new AsciiValidator( connectionWidget->editName ) );
+ connectionWidget->editName->setValidator( new AsciiValidator( TQT_TQOBJECT(connectionWidget->editName) ) );
enableAll( FALSE );
}
@@ -107,7 +107,7 @@ void DatabaseConnectionsEditor::newConnection()
void DatabaseConnectionsEditor::doConnect()
{
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
if ( listConnections->currentItem() == -1 ||
!listConnections->item( listConnections->currentItem() )->isSelected() ) { // new connection
// ### do error checking for duplicated connection names
@@ -149,7 +149,7 @@ void DatabaseConnectionsEditor::doConnect()
void DatabaseConnectionsEditor::currentConnectionChanged( const TQString &s )
{
-#ifndef QT_NO_SQL
+#ifndef TQT_NO_SQL
DatabaseConnection *conn = project->databaseConnection( s );
blockChanges = TRUE;
enableAll( conn != 0 );
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
@@ -45,25 +45,25 @@
static bool blockChanges = FALSE;
/*
- * Constructs a DatabaseConnectionsEditor which is a child of 'parent', with the
+ * Constructs a DatabaseConnectionsEditor which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*